==> deinja-0.0.1.tgz: package/main.js <==
const deinja = require("./src/deinja");

const list = [
  "いませんでした",
  "きませんでした",
  "ぎませんでした",
  "しませんでした",
  "ちませんでした",
  "にませんでした",
  "びませんでした",
  "みませんでした",
  "りませんでした",
  "いましょう",
  "きましょう",
  "ぎましょう",
  "しましょう",
  "ちましょう",
  "にましょう",
  "びましょう",
  "みましょう",
  "りましょう",
  "いじゃう",
  "いすぎる",
  "いちゃう",
  "いなさい",
  "いました",
  "いません",
  "きすぎる",
  "ぎすぎる",
  "きなさい",
  "ぎなさい",
  "きました",
  "ぎました",
  "きません",
  "ぎません",
  "しすぎる",
  "しちゃう",
  "しなさい",
  "しました",
  "しません",
  "ちすぎる",
  "ちなさい",
  "ちました",
  "ちません",
  "っちゃう",
  "っちゃう",
  "っちゃう",
  "にすぎる",
  "になさい",
  "にました",
  "にません",
  "びすぎる",
  "びなさい",
  "びました",
  "びません",
  "みすぎる",
  "みなさい",
  "みました",
  "みません",
  "りすぎる",
  "りなさい",
  "りました",
  "りません",
  "んじゃう",
  "んじゃう",
  "んじゃう",
  "いそう",
  "いたい",
  "いたら",
  "いだら",
  "いたり",
  "いだり",
  "います",
  "かせる",
  "がせる",
  "かない",
  "がない",
  "かれる",
  "がれる",
  "きそう",
  "ぎそう",
  "きたい",
  "ぎたい",
  "きます",
  "ぎます",
  "させる",
  "さない",
  "される",
  "しそう",
  "したい",
  "したら",
  "したり",
  "します",
  "たせる",
  "たない",
  "たれる",
  "ちそう",
  "ちたい",
  "ちます",
  "ったら",
  "ったら",
  "ったら",
  "ったり",
  "ったり",
  "ったり",
  "なせる",
  "なない",
  "なれる",
  "にそう",
  "にたい",
  "にます",
  "ばせる",
  "ばない",
  "ばれる",
  "びそう",
  "びたい",
  "びます",
  "ませる",
  "まない",
  "まれる",
  "みそう",
  "みたい",
  "みます",
  "りそう",
  "りたい",
  "ります",
  "わせる",
  "わない",
  "われる",
  "んだら",
  "んだら",
  "んだら",
  "んだり",
  "んだり",
  "んだり",
  "いた",
  "いだ",
  "いて",
  "いで",
  "えば",
  "える",
  "おう",
  "かず",
  "がず",
  "けば",
  "げば",
  "ける",
  "げる",
  "こう",
  "ごう",
  "さず",
  "した",
  "して",
  "せば",
  "せる",
  "そう",
  "たず",
  "った",
  "った",
  "った",
  "って",
  "って",
  "って",
  "てば",
  "てる",
  "とう",
  "なず",
  "ねば",
  "ねる",
  "のう",
  "ばず",
  "べば",
  "べる",
  "ぼう",
  "まず",
  "めば",
  "める",
  "もう",
  "らず",
  "れば",
  "れる",
  "ろう",
  "わず",
  "んだ",
  "んだ",
  "んだ",
  "んで",
  "んで",
  "んで",
  "い",
  "い",
  "え",
  "え",
  "き",
  "き",
  "ぎ",
  "ぎ",
  "け",
  "け",
  "げ",
  "げ",
  "し",
  "じ",
  "せ",
  "せ",
  "ぜ",
  "ち",
  "ち",
  "て",
  "て",
  "で",
  "に",
  "に",
  "ね",
  "ね",
  "ひ",
  "び",
  "び",
  "へ",
  "べ",
  "べ",
  "み",
  "み",
  "め",
  "め",
  "り",
  "り",
  "れ",
  "れ",
  "れ",
  "らせる",
  "らない",
  "られる",
  "られ",
  "れば"
];

const main = () => {
  for (let j = 0; j < 1000; j++) {
    for (let i = 0; i < list.length; i++) {
      const str = list[i];
      deinja.convert(str);
      deinja.convert(str + "あ");
    }
  }
};

const start = new Date().getTime();

main();

const time = new Date().getTime() - start;
console.info(time);

==> deinja-0.0.3.tgz: package/main.js <==
const deinja = require("./src/deinja");

const list = [
  "いませんでした",
  "きませんでした",
  "ぎませんでした",
  "しませんでした",
  "ちませんでした",
  "にませんでした",
  "びませんでした",
  "みませんでした",
  "りませんでした",
  "いましょう",
  "きましょう",
  "ぎましょう",
  "しましょう",
  "ちましょう",
  "にましょう",
  "びましょう",
  "みましょう",
  "りましょう",
  "いじゃう",
  "いすぎる",
  "いちゃう",
  "いなさい",
  "いました",
  "いません",
  "きすぎる",
  "ぎすぎる",
  "きなさい",
  "ぎなさい",
  "きました",
  "ぎました",
  "きません",
  "ぎません",
  "しすぎる",
  "しちゃう",
  "しなさい",
  "しました",
  "しません",
  "ちすぎる",
  "ちなさい",
  "ちました",
  "ちません",
  "っちゃう",
  "っちゃう",
  "っちゃう",
  "にすぎる",
  "になさい",
  "にました",
  "にません",
  "びすぎる",
  "びなさい",
  "びました",
  "びません",
  "みすぎる",
  "みなさい",
  "みました",
  "みません",
  "りすぎる",
  "りなさい",
  "りました",
  "りません",
  "んじゃう",
  "んじゃう",
  "んじゃう",
  "いそう",
  "いたい",
  "いたら",
  "いだら",
  "いたり",
  "いだり",
  "います",
  "かせる",
  "がせる",
  "かない",
  "がない",
  "かれる",
  "がれる",
  "きそう",
  "ぎそう",
  "きたい",
  "ぎたい",
  "きます",
  "ぎます",
  "させる",
  "さない",
  "される",
  "しそう",
  "したい",
  "したら",
  "したり",
  "します",
  "たせる",
  "たない",
  "たれる",
  "ちそう",
  "ちたい",
  "ちます",
  "ったら",
  "ったら",
  "ったら",
  "ったり",
  "ったり",
  "ったり",
  "なせる",
  "なない",
  "なれる",
  "にそう",
  "にたい",
  "にます",
  "ばせる",
  "ばない",
  "ばれる",
  "びそう",
  "びたい",
  "びます",
  "ませる",
  "まない",
  "まれる",
  "みそう",
  "みたい",
  "みます",
  "りそう",
  "りたい",
  "ります",
  "わせる",
  "わない",
  "われる",
  "んだら",
  "んだら",
  "んだら",
  "んだり",
  "んだり",
  "んだり",
  "いた",
  "いだ",
  "いて",
  "いで",
  "えば",
  "える",
  "おう",
  "かず",
  "がず",
  "けば",
  "げば",
  "ける",
  "げる",
  "こう",
  "ごう",
  "さず",
  "した",
  "して",
  "せば",
  "せる",
  "そう",
  "たず",
  "った",
  "った",
  "った",
  "って",
  "って",
  "って",
  "てば",
  "てる",
  "とう",
  "なず",
  "ねば",
  "ねる",
  "のう",
  "ばず",
  "べば",
  "べる",
  "ぼう",
  "まず",
  "めば",
  "める",
  "もう",
  "らず",
  "れば",
  "れる",
  "ろう",
  "わず",
  "んだ",
  "んだ",
  "んだ",
  "んで",
  "んで",
  "んで",
  "い",
  "い",
  "え",
  "え",
  "き",
  "き",
  "ぎ",
  "ぎ",
  "け",
  "け",
  "げ",
  "げ",
  "し",
  "じ",
  "せ",
  "せ",
  "ぜ",
  "ち",
  "ち",
  "て",
  "て",
  "で",
  "に",
  "に",
  "ね",
  "ね",
  "ひ",
  "び",
  "び",
  "へ",
  "べ",
  "べ",
  "み",
  "み",
  "め",
  "め",
  "り",
  "り",
  "れ",
  "れ",
  "れ",
  "らせる",
  "らない",
  "られる",
  "られ",
  "れば"
];

// const main = () => {
//   for (let j = 0; j < 1000; j++) {
//     for (let i = 0; i < list.length; i++) {
//       const str = list[i];
//       deinja.convert(str);
//       deinja.convert(str + "あ");
//     }
//   }
// };

let r;

// r = deinja.convert("愛したい");
// console.info(r);

// r = deinja.convert("しちゃいます");
// console.info(r);

r = deinja.convert("愛しちゃいます");
console.info(r);

const start = new Date().getTime();

// main();

const time = new Date().getTime() - start;
console.info(time);
